==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/RollingDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingDeploymentStrategyParamsFluent<A extends io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Long getIntervalSeconds();
  public A withIntervalSeconds(java.lang.Long intervalSeconds);
  public java.lang.Boolean hasIntervalSeconds();
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxSurge();
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxSurge();
  public A withMaxSurge(io.fabric8.kubernetes.api.model.IntOrString maxSurge);
  public java.lang.Boolean hasMaxSurge();
  public A withNewMaxSurge(java.lang.Integer intVal);
  public A withNewMaxSurge(java.lang.String strVal);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable();
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable);
  public java.lang.Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(java.lang.Integer intVal);
  public A withNewMaxUnavailable(java.lang.String strVal);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost();
  public io.fabric8.openshift.api.model.LifecycleHook buildPost();
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post);
  public java.lang.Boolean hasPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre();
  public io.fabric8.openshift.api.model.LifecycleHook buildPre();
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre);
  public java.lang.Boolean hasPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public java.lang.Long getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public java.lang.Long getUpdatePeriodSeconds();
  public A withUpdatePeriodSeconds(java.lang.Long updatePeriodSeconds);
  public java.lang.Boolean hasUpdatePeriodSeconds();
  public interface MaxSurgeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<N>>{
    public N and();
    public N endMaxSurge();
    
  }
  public interface MaxUnavailableNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface PostNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/RollingDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingDeploymentStrategyParamsFluent<A extends io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Long getIntervalSeconds();
  public A withIntervalSeconds(java.lang.Long intervalSeconds);
  public java.lang.Boolean hasIntervalSeconds();
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxSurge();
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxSurge();
  public A withMaxSurge(io.fabric8.kubernetes.api.model.IntOrString maxSurge);
  public java.lang.Boolean hasMaxSurge();
  public A withNewMaxSurge(java.lang.Integer intVal);
  public A withNewMaxSurge(java.lang.String strVal);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurge();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(io.fabric8.kubernetes.api.model.IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable();
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable);
  public java.lang.Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(java.lang.Integer intVal);
  public A withNewMaxUnavailable(java.lang.String strVal);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost();
  public io.fabric8.openshift.api.model.LifecycleHook buildPost();
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post);
  public java.lang.Boolean hasPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre();
  public io.fabric8.openshift.api.model.LifecycleHook buildPre();
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre);
  public java.lang.Boolean hasPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public java.lang.Long getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public java.lang.Long getUpdatePeriodSeconds();
  public A withUpdatePeriodSeconds(java.lang.Long updatePeriodSeconds);
  public java.lang.Boolean hasUpdatePeriodSeconds();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MaxSurgeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxSurgeNested<N>>{
    public N and();
    public N endMaxSurge();
    
  }
  public interface MaxUnavailableNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface PostNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RollingDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}
